@@ -14,6 +14,8 @@ from .CxPortalWebService import (
     get_query_id_by_language_group_and_query_name,
     get_name_of_user_who_marked_false_positive_from_comments_history,
     get_preset_list,
+    get_projects_display_data,
+    get_associated_group_list,
     get_result_path,
     get_results_for_scan,
     get_server_license_data,
@@ -25,6 +27,7 @@ from .CxPortalWebService import (
     import_preset,
     import_queries,
     lock_scan,
+    postpone_scan,
     unlock_scan,
 )
 
