@@ -1,4 +1,4 @@
-from ..configUtility import (
+from CheckmarxPythonSDK.utilities.configUtility import (
     get_config
 )
 
@@ -11,6 +11,9 @@ config_default = {
     "scope": "reporting_api",
     "client_id": "reporting_service_api",
     "client_secret": "014DF517-39D1-4453-B7B3-9930C563627C",
+    "timeout": 60,
+    "verify": False,
+    "cert": None,
 }
 
 config = get_config(config_default=config_default, section="CxReporting", prefix="cxreporting_")
