@@ -1,4 +1,4 @@
-from ..configUtility import (
+from CheckmarxPythonSDK.utilities.configUtility import (
     get_config
 )
 
@@ -8,6 +8,10 @@ config_default = {
     "account": None,
     "username": None,
     "password": None,
+    "scope": "sca_api access_control_api",
+    "timeout": 60,
+    "verify": False,
+    "cert": None,
 }
 
 config = get_config(config_default=config_default, section="CxSCA", prefix="cxsca_")
